# There have been no releases, so we use a git snapshot
%global gitdate         20130809
%global gittag          722a30ce258eb38bee0a834406aed60a06f32d1d
%global shorttag        %(cut -b -7 <<< %{gittag})
%global user            broune

Name:           memtailor
Version:        0
Release:        1.%{gitdate}.git%{shorttag}%{?dist}
Summary:        C++ library of special-purpose memory allocators

License:        BSD
URL:            https://github.com/%{user}/%{name}
Source0:        https://github.com/%{user}/%{name}/tarball/%{gittag}/%{user}-%{name}-%{shorttag}.tar.gz

BuildRequires:  gtest-devel
BuildRequires:  libtool

%description
Memtailor is a C++ library of special purpose memory allocators.  It
currently offers an arena allocator and a memory pool.

The main motivation to use a memtailor allocator is better and more
predictable performance than you get with new/delete.  Sometimes a
memtailor allocator can also be more convenient due to the ability to
free many allocations at one time.

The Memtailor memory pool is useful if you need to do many allocations
of a fixed size.  For example a memory pool is well suited to allocate
the nodes in a linked list.

You can think of the Memtailor arena allocator as being similar to stack
allocation.  Both kinds of allocation are very fast and require you to
allocate/deallocate memory in last-in-first-out order.  Arena allocation
has the further benefits that it stays within the C++ standard, it will
not cause a stack overflow, you can have multiple arena allocators at
the same time and allocation is not tied to a function invocation.

%package devel
Summary:        Development files for memtailor
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
Files for developing applications that use memtailor.

%prep
%setup -q -n %{user}-%{name}-%{shorttag}

# Every file is marked executable; only a few need to be.
find . -type f -perm /0111 | xargs chmod a-x
chmod a+x autogen.sh fixspace replace

# Fool the configure script into not downloading gtest
sed -e 's,gtest/src/gtest-all\.cc,include/gtest/gtest.h,' \
    -e 's,gtest/include,include/gtest,' \
    -e 's,-I`cd \$GTEST_PATH/gtest/; echo \$PWD`,,' \
    -i configure.ac

# Fool the tests into not compiling with gtest source
sed -i 's,\.\./src/gtest-all\.cc,gtest/gtest.h,' src/test/gtestInclude.cpp

# Link tests with the installed gtest library and update the C++ standard
sed -e 's/gnu++0x/gnu++11/' \
    -e 's/unittest_LDFLAGS.*/& -lgtest/' \
    -i Makefile.am

# Upstream doesn't generate the configure script
autoreconf -fi

%build
export GTEST_PATH=%{_prefix}
export GEST_LIBS="-lgtest"
export GTEST_VERSION=1.7.0
%configure --disable-static --with-gtest=yes

# Get rid of undesirable hardcoded rpaths; workaround libtool reordering
# -Wl,--as-needed after all the libraries.
sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    -e 's|CC=.g..|& -Wl,--as-needed|' \
    -i libtool

make %{?_smp_mflags}

%install
%make_install

# We don't want the libtool archive
rm -f %{buildroot}%{_libdir}/lib%{name}.la

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%check
export LD_LIBRARY_PATH=$PWD/.libs
make check

%files
%doc README.md
%license license.txt
%{_libdir}/lib%{name}.so.*

%files devel
%{_includedir}/%{name}/
%{_includedir}/%{name}.h
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Fri Sep  4 2015 Jerry James <loganjerry@gmail.com> - 0-1.20130809.git722a30c
- Initial RPM
